<?php

namespace CodeZone\Bible\Tests;

use CodeZone\Bible\CodeZone\Router\Controllers\CallbackController;
use CodeZone\Bible\CodeZone\Router\FastRoute\Routes;
use CodeZone\Bible\CodeZone\Router;
use CodeZone\Bible\Illuminate\Container\Container;
use function CodeZone\Bible\CodeZone\Router\container;
/** @internal */
final class RouterTest extends TestCase
{
    use HasRouter;
    /**
     * @test
     */
    public function it_registers() : void
    {
        $container = new Container();
        $router = Router::register(['container' => $container]);
        $this->assertInstanceOf(Router::class, $router);
        $this->assertTrue($container->has(Router::class));
        $this->assertInstanceOf(Container::class, Router::instance()->container);
        $this->assertInstanceOf(Container::class, $container->make(Router::class)->container);
        $this->assertInstanceOf(Container::class, container());
    }
    /**
     * @test
     */
    public function it_registers_callback_routes() : void
    {
        $router = $this->router();
        $dispatcher = $router->routes(function (Routes $r) {
            $r->get('/', function () {
                return 'Hello World';
            });
        });
        $routes = $dispatcher->dispatch('GET', '/');
        $this->assertEquals(CallbackController::class, $routes[1][0]);
        $this->assertEquals('handle', $routes[1][1]);
        $this->assertEquals('Hello World', $routes[1][2]['handler']());
    }
    /**
     * @test
     */
    public function it_registers_string_routes() : void
    {
        $router = $this->router();
        $dispatcher = $router->routes(function (Routes $r) {
            $r->get('/', Controller::class . '@request');
        });
        $routes = $dispatcher->dispatch('GET', '/');
        $this->assertEquals(Controller::class, $routes[1][0]);
        $this->assertEquals('request', $routes[1][1]);
    }
    /**
     * @test
     */
    public function it_registers_array_routes() : void
    {
        $router = $this->router();
        $dispatcher = $router->routes(function (Routes $r) {
            $r->get('/', [Controller::class, 'request']);
        });
        $routes = $dispatcher->dispatch('GET', '/');
        $this->assertEquals(Controller::class, $routes[1][0]);
        $this->assertEquals('request', $routes[1][1]);
    }
}
